v2.0 - Nautobot ChatOps Documentation

Skip to content

# v2.0 Release Notes

## v2.0.2 (2023-08-11)

### Changed

- #233 - Fixed App initialization when `[grafana]` extra is not installed.

## v2.0.1 (2023-08-08)

### Changed

- #228 - Move Contributing Changelog Fragments higher in documentation

## v2.0.0 (2023-08-02)

### Added

- #67 - Added the ability within Slack to mention the chat bot by name in a channel and in threads.
- #194 - Added Mattermost container for the development.
- #194 - Improved invoke tasks.
- #197 - Add a try/except block and error logger message when access_token missing from get_token() response.
- #202 - Added Ansible integration from nautobot-plugin-chatops-ansible.
- #203 - Added IP Fabric integration from nautobot-plugin-chatops-ipfabric.
- #204 - Added Arista CloudVision integration from nautobot-plugin-chatops-arista-cloudvision.
- #205 - Added Cisco Meraki integration from nautobot-plugin-chatops-meraki.
- #206 - Added Cisco ACI integration from nautobot-plugin-chatops-aci.
- #207 - Added Panorama integration from nautobot-plugin-chatops-panorama
- #208 - Added Grafana integration from nautobot-plugin-chatops-grafana.

### Changed

- #67 - Modified the clear command to not work within Slack threads.
- #196 - Update to microsoft IPs and correcting the one in the doc.
- #218 - Added `/clear` command to development Mattermost.
- #218 - Improved integration workers loading.
- #218 - Sorted App config and environment variables.
- #218 - Sorted pyproject configurations.

### Removed

- Removed support for Python 3.7